# This file was auto-generated by lib/slack/web/api/tasks/generate.rake

module Slack
  module Web
    module Api
      module Endpoints
        module Files
          #
          # Edit an existing comment on a file. Only the user who created a comment may make edits. Teams may configure a limited time window during which file comment edits are allowed.
          #
          # @option options [file] :file
          #   File containing the comment to edit.
          # @option options [Object] :id
          #   The comment to edit.
          # @option options [Object] :comment
          #   Text of the comment to edit.
          # @see https://api.slack.com/methods/files.comments
          # @see https://github.com/dblock/slack-api-ref/blob/master/methods/files.comments.json
          def files_comments(options = {})
            throw ArgumentError.new('Required arguments :file missing') if options[:file].nil?
            throw ArgumentError.new('Required arguments :id missing') if options[:id].nil?
            throw ArgumentError.new('Required arguments :comment missing') if options[:comment].nil?
            post('files.comments', options)
          end

          #
          # This method deletes a file from your team.
          #
          # @option options [file] :file
          #   ID of file to delete.
          # @see https://api.slack.com/methods/files.delete
          # @see https://github.com/dblock/slack-api-ref/blob/master/methods/files.delete.json
          def files_delete(options = {})
            throw ArgumentError.new('Required arguments :file missing') if options[:file].nil?
            post('files.delete', options)
          end

          #
          # This method returns information about a file in your team.
          #
          # @option options [file] :file
          #   File to fetch info for.
          # @see https://api.slack.com/methods/files.info
          # @see https://github.com/dblock/slack-api-ref/blob/master/methods/files.info.json
          def files_info(options = {})
            throw ArgumentError.new('Required arguments :file missing') if options[:file].nil?
            post('files.info', options)
          end

          #
          # This method returns a list of files within the team. It can be filtered and sliced in various ways.
          #
          # @option options [user] :user
          #   Filter files created by a single user.
          # @option options [Object] :ts_from
          #   Filter files created after this timestamp (inclusive).
          # @option options [Object] :ts_to
          #   Filter files created before this timestamp (inclusive).
          # @option options [Object] :types
          #   Filter files by type:
          #
          #   all - All files
          #   posts - Posts
          #   snippets - Snippets
          #   images - Image files
          #   gdocs - Google docs
          #   zips - Zip files
          #   pdfs - PDF files
          #
          #
          #   You can pass multiple values in the types argument, like types=posts,snippets.The default value is all, which does not filter the list.
          #   .
          # @see https://api.slack.com/methods/files.list
          # @see https://github.com/dblock/slack-api-ref/blob/master/methods/files.list.json
          def files_list(options = {})
            options = options.merge(user: users_id(options)['user']['id']) if options[:user]
            post('files.list', options)
          end

          #
          # This method allows you to create or upload an existing file.
          #
          # @option options [file] :file
          #   File contents via multipart/form-data.
          # @option options [Object] :content
          #   File contents via a POST var.
          # @option options [Object] :filetype
          #   Slack-internal file type identifier.
          # @option options [Object] :filename
          #   Filename of file.
          # @option options [Object] :title
          #   Title of file.
          # @option options [Object] :initial_comment
          #   Initial comment to add to file.
          # @option options [Object] :channels
          #   Comma-separated list of channel names or IDs where the file will be shared.
          # @see https://api.slack.com/methods/files.upload
          # @see https://github.com/dblock/slack-api-ref/blob/master/methods/files.upload.json
          def files_upload(options = {})
            throw ArgumentError.new('Required arguments :file missing') if options[:file].nil?
            throw ArgumentError.new('Required arguments :filename missing') if options[:filename].nil?
            post('files.upload', options)
          end
        end
      end
    end
  end
end
